-- Bufferpool Logical Reads per Transaction (BPLRTX)
-- So, why is BPLRTX the Most Important Cost metric? Glad you asked.
-- When DB2 wants to access data (either index pages or data pages), a Logical Read is performed against the bufferpool. 
-- If the data requested is not present in the bufferpool per the logical read request, then a Physical Read must be performed to disk to retrieve the page that was logically requested. 
-- If the logically requested data is already in the bufferpool, then the physical disk read is avoided. 
-- So, you will note that a request for data typically begins with a Logical request which may, or may not, result in a physical request.
-- There is a very strong correlation between Logical Reads and CPU consumption. The more Logical Reads that are performed in support of a transaction, the more CPU that is consumed. 
-- By improving physical design to reduce BPLRTX, you will successfully reduce CPU consumption, improve response times and query throughput, 
-- and avoid costly and unnecessary hardware upgrades.
-- Just remember: Logical Reads = CPU Consumption
-- To compute BPLRTX, first find the number of transactions from a database snapshot  by adding together the number of Commit Statements Attempted plus Rollback Statements Attempted.
-- TXCNT = Commits Attempted + Rollbacks Attempted
-- Next, find the total number of Logical Bufferpool Reads by adding together "Buffer pool data logical reads" plus "Buffer pool index logical reads".
-- BPLR = Buffer pool data logical reads + Buffer pool index logical reads
-- BPLR can be computed at the database level from the Database Snapshot; at the Bufferpool level, for each bufferpool from the Bufferpool Snapshot; and for each tablespace, 
-- at the tablespace level, from the tablespace snapshot. 
-- Unfortunately, DB2 does not report logical reads at the table level so a level of granularity is lost unless you assign one table per tablespace.
-- Finally, computing BPLRTX is easy: BPLRTX = BPLR / TXCNT

select 	(pool_data_l_reads + pool_index_l_reads+ pool_temp_data_l_reads+ pool_temp_index_l_reads) / 
		(commit_sql_stmts + rollback_sql_stmts + int_commits + int_rollbacks) as bplrtx
from sysibmadm.snapdb ;


