-- The Synchronous Read Percentage (SRP) metric:
-- When DB2 has good indexes available to retrieve rows for result sets, it will use synchronous I/O to access precisely just the index and data pages required. 
-- When indexes are missing, or the physical design is otherwise sub-optimal, DB2 will resort to using asynchronous prefetch I/O to scan index or data pages. 
-- Scans are "evil" and should be avoided as much as possible, especially for OLTP databases. The higher the SRP, the better.
-- Unfortunately, DB2 doesn't directly report Synchronous I/O numbers, but it does report Asynchronous I/O numbers and total counts for I/O to the bufferpools. 
-- So, in this formula, we first find the Asynchronous Read Percentage, then subtract this from 100 to find the SRP.
-- The formula is:
-- SRP = 100 - (((Asynchronous pool data page reads + Asynchronous pool index page reads) x 100) / (Buffer pool data physical reads + Buffer pool index physical reads))
-- which we can retrieve from the database as:
-- select 100 - (((pool_async_data_reads + pool_async_index_reads) * 100 ) / (pool_data_p_reads + pool_index_p_reads + 1)) as SRP from sysibmadm.snapdb where DB_NAME = 'DBNAME'

select 100 - (((pool_async_data_reads + pool_async_index_reads) * 100 ) / (pool_data_p_reads + pool_index_p_reads + 1)) as SRP from sysibmadm.snapdb where DB_NAME = current server ;


